==> qtjambi-qml-debuginfo-macos-6.5.10.jar: sources/QtJambiQml/QQmlContext_PropertyPair_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQml/qqmlcontext.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QQmlContext_PropertyPair(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlContext::PropertyPair")
    QQmlContext::PropertyPair *_ptr = reinterpret_cast<QQmlContext::PropertyPair *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new PropertyPair()
void __qt_construct_QQmlContext_PropertyPair(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct PropertyPair()")
    Q_UNUSED(__java_arguments)
    QQmlContext::PropertyPair *__qt_this = new(__qtjambi_ptr) QQmlContext::PropertyPair();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QQmlContext::PropertyPair::PropertyPair()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlContext_00024PropertyPair_initialize_1native__Lio_qt_qml_QQmlContext_00024PropertyPair_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlContext::PropertyPair::PropertyPair()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlContext_PropertyPair, sizeof(QQmlContext::PropertyPair), typeid(QQmlContext::PropertyPair), 0, false, &deleter_QQmlContext_PropertyPair, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new PropertyPair(QQmlContext::PropertyPair)
void __qt_construct_QQmlContext_PropertyPair_cref_QQmlContext_PropertyPair(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct PropertyPair(QQmlContext::PropertyPair)")
    jobject other0 = __java_arguments[0].l;
    const QQmlContext::PropertyPair& __qt_other0 = qtjambi_cast<const QQmlContext::PropertyPair&>(__jni_env, other0);
    QQmlContext::PropertyPair *__qt_this = new(__qtjambi_ptr) QQmlContext::PropertyPair(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QQmlContext::PropertyPair::PropertyPair(QQmlContext::PropertyPair)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlContext_00024PropertyPair_initialize_1native__Lio_qt_qml_QQmlContext_00024PropertyPair_2Lio_qt_qml_QQmlContext_00024PropertyPair_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlContext::PropertyPair::PropertyPair(QQmlContext::PropertyPair)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlContext_PropertyPair_cref_QQmlContext_PropertyPair, sizeof(QQmlContext::PropertyPair), typeid(QQmlContext::PropertyPair), 0, false, &deleter_QQmlContext_PropertyPair, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new PropertyPair{QString,QVariant}
void __qt_construct_QQmlContext_PropertyPair_QString_QVariant(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct PropertyPair{QString,QVariant}")
    jstring name0 = static_cast<jstring>(__java_arguments[0].l);
    QString __qt_name0 = qtjambi_cast<QString>(__jni_env, name0);
    jobject value1 = __java_arguments[1].l;
    QVariant __qt_value1 = qtjambi_cast<QVariant>(__jni_env, value1);
    QQmlContext::PropertyPair *__qt_this = new(__qtjambi_ptr) QQmlContext::PropertyPair{__qt_name0, __qt_value1};
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QQmlContext::PropertyPair::PropertyPair{QString,QVariant}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlContext_00024PropertyPair_initialize_1native__Lio_qt_qml_QQmlContext_00024PropertyPair_2Ljava_lang_String_2Ljava_lang_Object_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring name0,
 jobject value1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlContext::PropertyPair::PropertyPair{QString,QVariant}")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = name0;
        arguments[1].l = value1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlContext_PropertyPair_QString_QVariant, sizeof(QQmlContext::PropertyPair), typeid(QQmlContext::PropertyPair), 0, false, &deleter_QQmlContext_PropertyPair, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQmlContext::PropertyPair
void __qt_destruct_QQmlContext_PropertyPair(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlContext::PropertyPair")
    reinterpret_cast<QQmlContext::PropertyPair*>(ptr)->~PropertyPair();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlContext_00024PropertyPair_setName_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring name0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQmlContext::PropertyPair *__qt_this = QtJambiAPI::objectFromNativeId<QQmlContext::PropertyPair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString __qt_name0 = qtjambi_cast<QString>(__jni_env, name0);
        __qt_this->name = __qt_name0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlContext_00024PropertyPair_name_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQmlContext::PropertyPair *__qt_this = QtJambiAPI::objectFromNativeId<QQmlContext::PropertyPair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QString&  __qt_value = __qt_this->name;
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlContext_00024PropertyPair_setValue_1native_1cref_1QVariant__JLjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject value0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQmlContext::PropertyPair *__qt_this = QtJambiAPI::objectFromNativeId<QQmlContext::PropertyPair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QVariant __qt_value0 = qtjambi_cast<QVariant>(__jni_env, value0);
        __qt_this->value = __qt_value0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlContext_00024PropertyPair_value_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQmlContext::PropertyPair *__qt_this = QtJambiAPI::objectFromNativeId<QQmlContext::PropertyPair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QVariant&  __qt_value = __qt_this->value;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlContext_00024PropertyPair_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QQmlContext::PropertyPair *__qt_this = QtJambiAPI::objectFromNativeId<QQmlContext::PropertyPair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QQmlContext_PropertyPair(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QQmlContext::PropertyPair>("QQmlContext::PropertyPair", "io/qt/qml/QQmlContext$PropertyPair");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QQmlContext_PropertyPair, {
        ConstructorInfo{&__qt_construct_QQmlContext_PropertyPair, nullptr}
       ,ConstructorInfo{&__qt_construct_QQmlContext_PropertyPair_cref_QQmlContext_PropertyPair, "Lio/qt/qml/QQmlContext$PropertyPair;"}
       ,ConstructorInfo{&__qt_construct_QQmlContext_PropertyPair_QString_QVariant, "Ljava/lang/String;Ljava/lang/Object;"}
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlContext_PropertyPair);
    registerMetaType<QQmlContext::PropertyPair>("QQmlContext::PropertyPair");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qml-debuginfo-macos-6.6.3.jar: sources/QtJambiQml/QQmlContext_PropertyPair_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQml/qqmlcontext.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QQmlContext_PropertyPair(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlContext::PropertyPair")
    QQmlContext::PropertyPair *_ptr = reinterpret_cast<QQmlContext::PropertyPair *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new PropertyPair()
void __qt_construct_QQmlContext_PropertyPair(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct PropertyPair()")
    Q_UNUSED(__java_arguments)
    QQmlContext::PropertyPair *__qt_this = new(__qtjambi_ptr) QQmlContext::PropertyPair();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QQmlContext::PropertyPair::PropertyPair()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlContext_00024PropertyPair_initialize_1native__Lio_qt_qml_QQmlContext_00024PropertyPair_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlContext::PropertyPair::PropertyPair()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlContext_PropertyPair, sizeof(QQmlContext::PropertyPair), typeid(QQmlContext::PropertyPair), false, &deleter_QQmlContext_PropertyPair, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new PropertyPair(QQmlContext::PropertyPair)
void __qt_construct_QQmlContext_PropertyPair_cref_QQmlContext_PropertyPair(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct PropertyPair(QQmlContext::PropertyPair)")
    jobject other0 = __java_arguments[0].l;
    const QQmlContext::PropertyPair& __qt_other0 = qtjambi_cast<const QQmlContext::PropertyPair& >(__jni_env, other0);
    QQmlContext::PropertyPair *__qt_this = new(__qtjambi_ptr) QQmlContext::PropertyPair(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QQmlContext::PropertyPair::PropertyPair(QQmlContext::PropertyPair)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlContext_00024PropertyPair_initialize_1native__Lio_qt_qml_QQmlContext_00024PropertyPair_2Lio_qt_qml_QQmlContext_00024PropertyPair_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlContext::PropertyPair::PropertyPair(QQmlContext::PropertyPair)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlContext_PropertyPair_cref_QQmlContext_PropertyPair, sizeof(QQmlContext::PropertyPair), typeid(QQmlContext::PropertyPair), false, &deleter_QQmlContext_PropertyPair, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new PropertyPair{QString,QVariant}
void __qt_construct_QQmlContext_PropertyPair_QString_QVariant(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct PropertyPair{QString,QVariant}")
    jstring name0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_name0 = qtjambi_cast<QString>(__jni_env, name0);
    jobject value1 = __java_arguments[1].l;
    QVariant  __qt_value1 = qtjambi_cast<QVariant >(__jni_env, value1);
    QQmlContext::PropertyPair *__qt_this = new(__qtjambi_ptr) QQmlContext::PropertyPair{__qt_name0, __qt_value1};
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QQmlContext::PropertyPair::PropertyPair{QString,QVariant}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlContext_00024PropertyPair_initialize_1native__Lio_qt_qml_QQmlContext_00024PropertyPair_2Ljava_lang_String_2Ljava_lang_Object_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring name0,
 jobject value1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlContext::PropertyPair::PropertyPair{QString,QVariant}")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = name0;
        arguments[1].l = value1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlContext_PropertyPair_QString_QVariant, sizeof(QQmlContext::PropertyPair), typeid(QQmlContext::PropertyPair), false, &deleter_QQmlContext_PropertyPair, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQmlContext::PropertyPair
void __qt_destruct_QQmlContext_PropertyPair(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlContext::PropertyPair")
    reinterpret_cast<QQmlContext::PropertyPair*>(ptr)->~PropertyPair();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlContext_00024PropertyPair_setName_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring name0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQmlContext::PropertyPair *__qt_this = QtJambiAPI::objectFromNativeId<QQmlContext::PropertyPair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString  __qt_name0 = qtjambi_cast<QString>(__jni_env, name0);
        __qt_this->name = __qt_name0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlContext_00024PropertyPair_name_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQmlContext::PropertyPair *__qt_this = QtJambiAPI::objectFromNativeId<QQmlContext::PropertyPair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QString&  __qt_value = __qt_this->name;
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlContext_00024PropertyPair_setValue_1native_1cref_1QVariant__JLjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject value0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQmlContext::PropertyPair *__qt_this = QtJambiAPI::objectFromNativeId<QQmlContext::PropertyPair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QVariant  __qt_value0 = qtjambi_cast<QVariant >(__jni_env, value0);
        __qt_this->value = __qt_value0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlContext_00024PropertyPair_value_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQmlContext::PropertyPair *__qt_this = QtJambiAPI::objectFromNativeId<QQmlContext::PropertyPair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QVariant&  __qt_value = __qt_this->value;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlContext_00024PropertyPair_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QQmlContext::PropertyPair *__qt_this = QtJambiAPI::objectFromNativeId<QQmlContext::PropertyPair>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QQmlContext_PropertyPair(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QQmlContext::PropertyPair>("QQmlContext::PropertyPair", "io/qt/qml/QQmlContext$PropertyPair");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QQmlContext_PropertyPair, {
        ConstructorInfo(&__qt_construct_QQmlContext_PropertyPair, nullptr)
       ,ConstructorInfo(&__qt_construct_QQmlContext_PropertyPair_cref_QQmlContext_PropertyPair, "Lio/qt/qml/QQmlContext$PropertyPair;")
       ,ConstructorInfo(&__qt_construct_QQmlContext_PropertyPair_QString_QVariant, "Ljava/lang/String;Ljava/lang/Object;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlContext_PropertyPair);
    registerMetaType<QQmlContext::PropertyPair>("QQmlContext::PropertyPair");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
